#
# spec file for package lightdm-gtk-greeter
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 2.0
Name:           lightdm-gtk-greeter
Version:        2.0.2
Release:        2.2
Summary:        Simple display manager (GTK+ greeter)
License:        GPL-3.0+
Group:          System/X11/Displaymanagers
Url:            https://launchpad.net/lightdm-gtk-greeter
Source:         https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.gz
Source1:        https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  exo-tools
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.5
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(liblightdm-gobject-1) >= 1.3.5
BuildRequires:  pkgconfig(x11)
Requires:       %{name}-branding >= %{version}
Requires:       lightdm
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-lang
Recommends:     gnome-themes-accessibility
Provides:       lightdm-greeter

%description
A LightDM greeter that uses the GTK+ toolkit.
This is the reference implementation of a LightDM greeter based on the Gtk
toolkit.

%package branding-upstream
Summary:        Upstream branding of %{name}
Group:          System/X11/Displaymanagers
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: /etc/lightdm/lightdm-gtk-greeter.conf: Determines a number of greeter
#BRAND: settings, in particular the background image.

%description branding-upstream
This package provides the upstream look and feel for lightdm-gtk-greeter.

%lang_package

%prep
%setup -q
sed -i 's|$(datadir)/doc|%{_docdir}|g' data/Makefile.am

# Remove __DATE__ and __TIME__.
BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{H}:%{M}')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{b} %{d} %{Y}')
sed -i "s/__TIME__/\"$BUILD_TIME\"/" $(grep -rl '__TIME__')
sed -i "s/__DATE__/\"$BUILD_DATE\"/" $(grep -rl '__DATE__')

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure
make %{?_smp_mflags} V=1

%install
%make_install

%if 0%{?suse_version} >= 1320
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/lightdm-default-greeter.desktop
ln -s %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop \
  %{buildroot}%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif

%fdupes %{buildroot}
%find_lang %{name} %{?no_lang_C}

%post
update-alternatives --install \
  %{_datadir}/xgreeters/lightdm-default-greeter.desktop \
  lightdm-default-greeter.desktop \
  %{_datadir}/xgreeters/lightdm-gtk-greeter.desktop \
  20

%postun
if [ "$1" = 0 ]; then
    update-alternatives --remove \
      lightdm-default-greeter.desktop \
      %{_datadir}/xgreeters/lightdm-gtk-greeter.desktop
fi

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_sbindir}/%{name}
%{_datadir}/icons/hicolor/*/places/*
%dir %{_datadir}/xgreeters/
%{_datadir}/xgreeters/lightdm-gtk-greeter.desktop
%if 0%{?suse_version} >= 1320
%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%else
%ghost %attr(0644,root,root) %{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop

%files branding-upstream
%defattr(-,root,root)
%dir %{_sysconfdir}/lightdm/
%config(noreplace) %{_sysconfdir}/lightdm/lightdm-gtk-greeter.conf

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Oct  6 2016 sor.alexei@meowr.ru
- Update to version 2.0.2:
  * Add support for lightdm 1.19.2+.
  * Include a badge for Budgie desktop (lp#1568494).
  * Fix solid colour instead of background image for some themes
    (lp#1458330).
  * Restore user background after changing display setup.
  * Correct login box blinking on login.
  * Replace a number of build-breaking deprecations.
  * Update translations.
- Remove lightdm-gtk-greeter-fix-fail-return-value.patch,
  lightdm-gtk-greeter-lightdm-1.19.2-api.patch: fixed upstream.
* Sat Oct  1 2016 sor.alexei@meowr.ru
- Add lightdm-gtk-greeter-fix-fail-return-value.patch: Fix
  - Wreturn-type for fails.
- Use tarball signing.
* Sun Sep 25 2016 sor.alexei@meowr.ru
- Add lightdm-gtk-greeter-lightdm-1.19.2-api.patch: Use new API
  introduced in LightDM 1.19.2.
* Sun Oct 18 2015 ronisbr@gmail.com
- Version bump to 2.0.1.
- drop patches:
    lightdm-gtk-greeter-use-new-autologin-api.patch
    lightdm-gtk-greeter-fix-cursor.patch
    lightdm-gtk-greeter-fix-background.patch
    lightdm-gtk-greeter-improve-background-scaling.patch
    lightdm-gtk-greeter-fix-ui.patch
    lightdm-gtk-greeter-fix-login.patch
    lightdm-gtk-greeter-invalid-last_session.patch
    lightdm-gtk-greeter-handle-invalid-user.patch
* Tue Jul 28 2015 tiwai@suse.de
- fix update-alternative usage for Leap 42.1 (boo#939693)
* Sat Feb  8 2014 gber@opensuse.org
- adjust update-alternative usage to packaging policy
  (see http://lists.opensuse.org/opensuse-packaging/2014-02/msg00024.html)
* Mon Jan  6 2014 gber@opensuse.org
- add lightdm-gtk-greeter-handle-invalid-user.patch in order to fix
  a NULL pointer dereference after authentication of an invalid
  username has failed (bnc#857303)
* Thu Oct 10 2013 rmilasan@suse.com
- add lightdm-gtk-greeter-invalid-last_session.patch
  fix segfault when last_session is an invalid session (lp#1161883)
* Wed Oct  2 2013 gber@opensuse.org
- add lightdm-gtk-greeter-fix-login.patch in order to fix
  login/unlock detection
* Thu Jan 31 2013 gber@opensuse.org
- add lightdm-gtk-greeter-fix-cursor.patch in order to fix the
  cursor theme by setting the cursor after selecting a GTK theme
  (lp#1024482)
- add lightdm-gtk-greeter-fix-background.patch in order to fix the
  background image not being displayed when the pixmap does not
  have an alpha channel (lp#1086199)
- add lightdm-gtk-greeter-improve-background-scaling.patch which
  scales the background pixmap while preserving the aspect until
  width and height are at least as big as the screen width and
  height, then clips as needed
- add lightdm-gtk-greeter-fix-ui.patch with various usability
  fixes, in particular switch back to a tree view inside a scrolled
  window in order make it usable with a lot of users
* Tue Jan 15 2013 gber@opensuse.org
- update to version 1.3.1
  - drop custom icons now that there's a config option for the icon
    theme
  - rename the 'Login' button to 'Unlock' when the user is already
    logged in
  - don't hide the login box when cancel is pressed, instead
    refresh the prompt box to show the correct username prompt
  - hide the Cancel button, useless with the userlist combobox
  - properly center the login window after a resize
  - add names to widgets to ease theming
  - replace the userlist's treeview with a combobox
  - document the option to show the language chooser
  - add a config option to set the path to the logo image
  - add a config option to set the icon theme
  - use a known icon name for the accessibility menu
  - remember the last session used
- added lightdm-gtk-greeter-use-new-autologin-api.patch in order to
  use the new autologin API in liblightdm-gobject-1 >= 1.3.5
  (backported from upstream git)
* Wed May 30 2012 gber@opensuse.org
- update to version 1.1.6
  - fix 'Large Font' option for fontnames containing spaces
  - fix 'Cancel' button action, and clear the error label
  - add missing include for setlocale
  - updated translations
* Sat Apr  7 2012 gber@opensuse.org
- initial packaging
